<?php

namespace Elemailer\Integrations\Elementor\Actions;

defined('ABSPATH') || exit;

use \Elementor\Controls_Manager;
use \Elementor\Utils;


/**
 * all hook related class for activating some extra functionality based on elementor
 *
 * @author elEmailer
 * @since 1.0.0
 */
class Hooks
{
    use \Elemailer\Traits\Singleton;

    /**
     * initial function of this class
     *
     * @since 1.0.0
     */
    public function trigger_elementor_free_actions()
    {
        // add template select control in elementor form widget
        add_action('elementor/element/form/section_email/before_section_end', [$this, 'email_template_selector'], 10, 2);

        // add template select control in elementor form widget
        add_action('elementor/element/form/section_email_2/before_section_end', [$this, 'email2_template_selector'], 10, 2);

        // add custom background control in section control
        add_action('elementor/element/section/section_background/before_section_end', [$this, 'section_background'], 10, 2);
        // add custom body settings control in document setting
        add_action('elementor/documents/register_controls', [$this, 'register_document_controls']);

        // action for wc email dynamic tag
        add_action('elementor/controls/register', [$this, 'register_random_number_dynamic_tag']);

        // remove container experiement inside elemailer since @2.6
        add_action( 'elementor/experiments/default-features-registered', [$this, 'remove_container_experiment'],1);
        add_filter( 'elementor/admin/localize_settings', [$this, 'remove_all_experiment_requirement'],1);

        add_action( 'elementor/css-file/post/parse', [$this, 'add_custom_css'],1);

    }

    /**
     * function for activate elementor pro functionality
     *
     * @return void
     * @since 1.0.0
     */
    public function trigger_elementor_pro_actions()
    {
        // elementor form submission catch hook
         //@since v1.0.3 after it introduced Form_Actions_Registrar class to add control

        if(class_exists('\ElementorPro\Modules\Forms\Registrars\Form_Actions_Registrar')){

            add_action('elementor_pro/forms/actions/register', [$this, 'trigger_elementor_form_submission_new']);
            add_action( 'elementor_pro/forms/actions/register', [ $this, 'add_subscriber_action_on_form_submission_new']);

        }else{ // Fallback for older releases before 3.5 pro ie: 3.4.2 we will remove it in future

            add_action('elementor_pro/forms/form_submitted', [$this, 'trigger_elementor_form_submission']);
            // elementor form submission custom action add
            add_action( 'elementor_pro/init', [ $this, 'add_subscriber_action_on_form_submission']);

        }

    }

    /**
     * elementor missing notice function
     *
     * @return void
     * @since 1.0.0
     */
    public function register_random_number_dynamic_tag( $controls_manager )
    {
        // Here its safe to include our action class file
        include_once( 'email-dynamic-tag.php' );

        $controls_manager->register( new \Elemailer_WC_Email_Dynamic_Tag );
    }

    /**
     * catch elementor pro form submission function - 3.5 pro new version support
     *
     * @param object $module
     * @since 1.0.3
     * to fix depreceation
     */
    public function trigger_elementor_form_submission_new($module)
    {
        // override email class of elementor pro
        $module->register(new Void_Email());

        // override email2 class of elementor pro
        $module->register(new Void_Email2());
    }

    /**
     * catch elementor pro form submission function
     *
     * @param object $module
     * @since 1.0.0
     */
    public function trigger_elementor_form_submission($module)
    {
        // override email class of elementor pro
        $module->add_form_action('email', new Void_Email());

        // override email2 class of elementor pro
        $module->add_form_action('email2', new Void_Email2());
    }

    /**
     * add subscriber during elementor pro custom submission hook function 3.6 pro new version support
     *
     * @return void
     * @since 2.0.1
     * to fix depreceation
     */
    public function add_subscriber_action_on_form_submission_new($actions_registrar){
        // Here its safe to include our action class file
        include_once( 'subscriber-handler.php' );
        
        $actions_registrar->register( new Subscriber_Handler() );

    }

    /**
     * add subscriber during elementor pro custom submission hook function
     *
     * @return void
     * @since 1.0.0
     */
    public function add_subscriber_action_on_form_submission(){
        // Here its safe to include our action class file
        include_once( 'subscriber-handler.php' );
        
        // Instantiate the action class
        $subscriber_handler = new Subscriber_Handler();
    
        // Register the action with form widget
        \ElementorPro\Plugin::instance()->modules_manager->get_modules( 'forms' )->add_form_action( $subscriber_handler->get_name(), $subscriber_handler );
    }

    /**
     * option for selecting void email template function in form widget
     *
     * @param object $element
     * @param array $args
     * @since 1.0.0
     */
    public function email_template_selector($element, $args)
    {
        // add a control
        $element->add_control(
            'show_elemailer_email_template_selector',
            [
                'label' => esc_html__('Use Elemailer Template', 'elemailer'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'elemailer'),
                'label_off' => esc_html__('No', 'elemailer'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $element->add_control(
            'select_elemailer_email_template',
            [
                'label' => esc_html__('Choose Elemailer Template', 'elemailer'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => \Elemailer\App\Form_Template\Action::instance()->get_all_template(),
                'condition' => [
                    'show_elemailer_email_template_selector' => 'yes',
                ],
            ]
        );
    }

    /**
     * option for selecting void email template function in form widget
     *
     * @param object $element
     * @param array $args
     * @since 1.0.0
     */
    public function email2_template_selector($element, $args)
    {
        // add a control
        $element->add_control(
            'show_elemailer_email_template_selector_2',
            [
                'label' => esc_html__('Use Elemailer template', 'elemailer'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'elemailer'),
                'label_off' => esc_html__('No', 'elemailer'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $element->add_control(
            'select_elemailer_email_template_2',
            [
                'label' => esc_html__('Select Elemailer template', 'elemailer'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => \Elemailer\App\Form_Template\Action::instance()->get_all_template(),
                'condition' => [
                    'show_elemailer_email_template_selector_2' => 'yes',
                ],
            ]
        );
    }

    /* @since 4.0.1 print custom css in the template */ 
    public function add_custom_css($post_css){

        $document = \Elementor\Plugin::$instance->documents->get( $post_css->get_post_id() );
        $custom_css = $document->get_settings( 'elemailer_root_custom_css' );

        if ( empty( $custom_css ) ) {
            return;
        }

        $custom_css = str_replace( 'selector', $document->get_css_wrapper_selector(), $custom_css );

        $custom_css = str_replace("\n", "", $custom_css);
        $custom_css = str_replace(" ", "", $custom_css);
        $custom_css_min = preg_replace("/([0-9]*px(?!;))/", "$1 ", $custom_css);

        $post_css->get_stylesheet()->add_raw_css( $custom_css_min );

    }

    /**
     * Remove the container experiement. TO DO: in future further modification will be needed for sure.
     * @since 2.6
     */
    public function remove_container_experiment( $document ) {
        if(isset( $_GET['post']) && in_array( get_post_type($_GET['post']), ['em-form-template', 'em-emails-template'] ) ){
            $document->remove_feature( 'container');  
             
            // patch for fixing fatal error on elementor loop builder as it reqires container. So we are initializing fake loop 
            //require_once('container.php');
            // @since 4.0.7 we no longer need it because of remove_all_experiement_requirement system. we will remove it later
            // patch for fixing fatal error on elementor loop builder as it reqires container. So we are initializing fake loop
            // require_once('container.php');
         
    
        }
    }

    public function remove_all_experiment_requirement( $settings ) {
          if(isset( $_GET['post']) && in_array( get_post_type($_GET['post']), ['em-form-template', 'em-emails-template'] ) ){
           
            $settings['experiments']='';
            
            return $settings; //return empty expreiemt list for our post types
         
          }
          return $settings; // return original value
    }

    /**
     * custom control for elemailer email body settings
     * @since 2.6
     */

    public function register_document_controls($document)
    {
    
    if ( ! $document instanceof \Elementor\Core\DocumentTypes\PageBase || ! $document::get_property( 'has_elements' ) || ! in_array( get_post_type($document->get_main_id()), ['em-form-template', 'em-emails-template'] ) ) {
        return;
    }
 

    $document->start_controls_section(
        'elemailer_settings',
        [
            'label' => esc_html__( 'Elemailer Email Settings', 'elemailer' ),
            'tab' => \Elementor\Controls_Manager::TAB_SETTINGS,
            'classes'=> 'elemailer-main-settings',
        ]
    );

    $document->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [   
                'label_block'=> true,
                'show_label'=> true,
                'name' => 'elemailer_body_background',
                'types' => [ 'classic' ],
                'selector' => '{{WRAPPER}}',
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                        'label' => esc_html__( 'Email Body Background', 'elemailer' ),
                        'description' => 'Set a background for the body of your email. Keep in mind some of the settings might not work in some email platforms due to not having the support for modern CSS.',             
                    ],
                    'color' => [
                            'default' => '#FFFFFF',
                            'dynamic' => [
                                'active' => false,
                            ],
                            'global' => [
                                'active' => false,
                            ],
                    ],
                    'image' =>[
                        'responsive' => false,
                    ],
                    'position' =>[
                        'responsive' => false,
                    ],
                    'attachment' =>[
                        'responsive' => false,
                    ],
                    'repeat' =>[
                        'responsive' => false,
                    ],
                    'size' =>[
                        'responsive' => false,
                    ],
                ],
    
                
            ],

        );

    //@since 3.6
    $document->add_control(
        'elemailer_body_default_section_padding',
        [
            'label'         => __( 'Section default padding', 'elemailer' ),
            'type'          => Controls_Manager::DIMENSIONS,
            'description'   => __('The default value is set to 10px if left empty. Set all to 0 if you do not want section to section padding','elemailer'),
            'size_units'    => [ 'px', '%' ],
            'default'       => [
                    'top' => '10',
                    'right' => '10',
                    'bottom' => '10',
                    'left' => '10',
                    'unit' => 'px',
                    'isLinked' => true,
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-row .elementor-column .elementor-element-populated .elementor-widget-wrap,{{WRAPPER}} .elementor-column .elementor-element-populated.elementor-widget-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    ); 

    $document->add_control(
        'elemailer_root_custom_css',
        [
            'label' => esc_html__( 'Email Custom CSS', 'elemailer' ),
            'description'=> esc_html__( 'Warning: It might seem easy enough to add any css and view that on your email template but keep in mind not every email template supports all modern css. Infact the support is very limited. So use custom css at your own risk', 'elemailer' ),
            'type' => \Elementor\Controls_Manager::CODE,
            'separator' => 'before',
            'label_block' => true,
            'render_type' => 'ui',
            'language' => 'css',
            'classes' => 'elementor-panel-alert elementor-panel-alert-warning',
            'rows' => 20,
        ]
    );


     $document->add_control(
        'elemailer_export_html_button',
        [
            'type' => \Elementor\Controls_Manager::BUTTON,
            'separator' => 'before',
            'button_type' => 'default',
            'text' => esc_html__( 'Export', 'elemailer' ),
            'event' => 'elemailer:email:export',
            'label' => 'Export as HTML file',
        ]
    );

    // since @3.5 email teser fields under setting gear icon for elemailer 
    
    $document->add_control(
            'elemailer_preview_email_beginning',
            [               
                'separator' => 'before',
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => __( '<b style="color:orange; font-size:13px;">Send Test Email</b><br><br>You can send test email to your real email using this and see how the design looks in real emails without sending it to your visitors first. Please keep in mind any dynamic content will not be rendered in email such as shortcodes, WooCommerce order data', 'elemailer' ),
                'content_classes' => 'elementor-control-field-description',
            ]
    );

    $document->add_control(
        'elemailer_preview_email',
        [
            'type' => \Elementor\Controls_Manager::TEXT,
            'label' => esc_html__( 'Enter valid email', 'elemailer' ),
        ]
    );

    $document->add_control(
        'elemailer_preview_email_send',
        [
            'type' => \Elementor\Controls_Manager::BUTTON,
            'button_type' => 'default',
            'text' => esc_html__( 'Send', 'elemailer' ),
            'event' => 'elemailer:email:preview',
        ]
    );

    $document->add_control(
            'elemailer_templateid',
            [
                'label' => esc_html__( 'Current template ID', 'elemailer' ),
                'type' => \Elementor\Controls_Manager::HIDDEN,
                'default' => get_the_ID(),
            ]
    );

    $document->add_control(
            'elemailer_testemail_nonce',
            [
                'type' => \Elementor\Controls_Manager::HIDDEN,
                'default' => wp_create_nonce( 'elemailer_test_email_nonce' ),
            ]
    );

    $document->add_control(
            'elemailer_testemail_siteurl',
            [
                'type' => \Elementor\Controls_Manager::HIDDEN,
                'default' => admin_url('admin-ajax.php'),
            ]
    );




    $document->end_controls_section();
        
    }

    /**
     * custom control add in section of elementor for adding background
     *
     * @param object $element
     * @param array $args
     * @return void
     * @since 1.0.0
     */
    public function section_background($element, $args)
    {
        // return if this is not post type of elemailer
        $post_type = get_post_type();

        if (
            ! in_array( $post_type, ['em-form-template', 'em-emails-template'] ) &&
            \Elementor\Plugin::$instance->editor->is_edit_mode()
        ) {
            return;
        }

        $element->add_control(
            'section_background_type',
            [
                'label' => __('Background Type', 'elemailer'),
                'type' => Controls_Manager::SELECT,
                'separator' => 'before',
                'default' => 'color',
                'options' => [
                    'color'  => __('Color', 'elemailer'),
                    'image' => __('Image', 'elemailer'),
                ],
            ]
        );

        $element->add_control(
            'section_background_color',
            [
                'label' => __('Background Color', 'elemailer'),
                'type' => Controls_Manager::COLOR,
                // 'separator' => 'before',
                'condition' => [
                    'section_background_type' => 'color',
                ],
                'selectors' => [
                    '{{WRAPPER}} > .elementor-container' => 'background: {{VALUE}};',
                ],
                'dynamic' => [
					'active' => false,
				],
				'global' => [
					'active' => false,
				],
            ]
        );

        $element->add_control(
            'section_background_image',
            [
                'label' => __('Choose Image', 'elemailer'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'section_background_type' => 'image',
                ],
                'selectors' => [
                    '{{WRAPPER}} > .elementor-container' => 'background: url(\'{{URL}}\') no-repeat center;',
                ],
            ]
        );
    }
}
